Python library for Tamin.ir API
=====================================

This is a Python library for the `Tamin.ir
API <https://Tamin.ir>`__. Using this, you can interact
with Tamin.ir from your Python applications. It supports Python
2.7 and Python 3 (3.6+). For more about information about the
tamin.ir API, visit https://Tamin.ir.

Please see `README <https://github.com/mazafard/tamin-sdk>`__ on the
project page to get started.
